<?php

/**
 * AbraFlex Order status changer.
 *
 * @author     Vítězslav Dvořák <vitezslav.dvorak@spojenet.cz>
 * @copyright  2022 Spoje.Net
 */
define('APP_NAME', 'AbraFlexiOrderChanger');
require_once /var/lib/composer/abraflexi-order-status-changer/autoload.php';

if (file_exists('/etc/abraflexi-order-status-changer/.env')) {
    \Ease\Shared::singleton()->loadConfig('/etc/abraflexi-order-status-changer/.env', true);
}

foreach (['DOCUMENTID','ABRAFLEXI_URL','ABRAFLEXI_LOGIN','ABRAFLEXI_PASSWORD','ABRAFLEXI_COMPANY','EASE_LOGGER'] as $cfgKey){
    if(empty(\Ease\Functions::cfg($cfgKey))){
        echo 'Requied configuration '.$cfgKey.' is not set.';
        exit(1);
    }
}

$orderer = new \AbraFlexi\ObjednavkaPrijata(\Ease\Functions::cfg('DOCUMENTID'));

function stateExtract($noteRaw) {
    $state = null;
    if (strstr($noteRaw, ':')) {
        foreach (preg_split('/\n/', $noteRaw) as $noteLine) {
            if (stristr($noteLine, \Ease\Functions::cfg('ORDER_NOTE_KEYWORD','Note:'))) {
                $state = trim(preg_split('/: /', $noteLine, 2)[1], " \t\n\r\0\x0B'\"");
            }
        }
    }
    return $state;
}

//  AbraFlexi States Availble:
//
//    Připraveno (stavDoklObch.pripraveno)
//    Schváleno (stavDoklObch.schvaleno)
//    Částečně na cestě (stavDoklObch.castecneNaCeste)
//    Na cestě (stavDoklObch.naCeste)
//    Částečně vydáno/přijato (stavDoklObch.castVydano)
//    Vydáno/přijato (stavDoklObch.vydano)
//    Částečně hotovo (stavDoklObch.castHotovo)

    switch (stateExtract($orderer->getDataValue('poznam'))) {
        case 'Hotovo':
            $stavUzivK = 'stavDoklObch.hotovo';
            break;
        case 'Stornována':
            $stavUzivK = 'stavDoklObch.storno';
            break;
        case 'Nevyřízená':
        case 'Nevyzvednutá':
        case 'Probíhá příprava':
        case 'Vyřízena':
        case 'Vyřizuje se':
        case '':
        default:
            $stavUzivK = 'stavDoklObch.nespec';
    }

    if ($stavUzivK) {
        $orderer->stripBody();
        $orderer->setDataValue('stavUzivK', $stavUzivK);
        $result = $orderer->sync();
        $orderer->addStatusMessage('Change to ' . $stavUzivK, $result ? 'success' : 'error' );
    } else {
        $orderer->addStatusMessage(_('Order without known state'), 'warning');
    }

